<?xml version="1.0" encoding="utf-8"?><!DOCTYPE TS><TS language="ca-AD" sourcelanguage="en" version="2.0">
<context>
    <name>AboutDialogBase</name>
    <message>
        <location filename="res/AboutDialogBase.ui" line="38"/>
        <source>About Barrier</source>
        <translation type="finished">En quant a Barrier</translation>
    </message>
    <message utf8="true">
        <location filename="res/AboutDialogBase.ui" line="53"/>
        <source>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2016 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Barrier is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Barrier is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Barrier GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2016 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Barrier is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Barrier is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Barrier GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="140"/>
        <source>Unknown</source>
        <translation type="finished">Desconegut </translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="124"/>
        <source>Version:</source>
        <translation type="finished">Versió:</translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="163"/>
        <source>&amp;Ok</source>
        <translation type="finished">Ok</translation>
    </message>
</context>
<context>
    <name>ActionDialogBase</name>
    <message>
        <location filename="res/ActionDialogBase.ui" line="14"/>
        <source>Configure Action</source>
        <translation type="finished">Configurar Acció</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="20"/>
        <source>Choose the action to perform</source>
        <translation type="finished">Tria l'acció a realitzar</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="26"/>
        <source>Press a hotkey</source>
        <translation type="finished">Prem una tecla d'accés ràpid</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="36"/>
        <source>Release a hotkey</source>
        <translation type="finished">Allibera una tecla d'accés ràpid</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="43"/>
        <source>Press and release a hotkey</source>
        <translation type="finished">Prem i allibera una tecla d'accés ràpid</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="69"/>
        <source>only on these screens</source>
        <translation type="finished">només en aquestes pantalles</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="119"/>
        <source>Switch to screen</source>
        <translation type="finished">Canviar de pantalla</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="150"/>
        <source>Switch in direction</source>
        <translation type="finished">Canviar de direcció</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="174"/>
        <source>left</source>
        <translation type="finished">esquerra</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="179"/>
        <source>right</source>
        <translation type="finished">dreta</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="184"/>
        <source>up</source>
        <translation type="finished">amunt</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="189"/>
        <source>down</source>
        <translation type="finished">avall</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="201"/>
        <source>Lock cursor to screen</source>
        <translation type="finished">Bloquejar el cursor a la pantalla</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="225"/>
        <source>toggle</source>
        <translation type="finished">intercanviar</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="230"/>
        <source>on</source>
        <translation type="finished">on</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="235"/>
        <source>off</source>
        <translation type="finished">off</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="248"/>
        <source>This action is performed when</source>
        <translation type="finished">Aquesta acció es realitza quan</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="254"/>
        <source>the hotkey is pressed</source>
        <translation type="finished">s'ha premut la tecla d'accés ràpid</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="264"/>
        <source>the hotkey is released</source>
        <translation type="finished">s'ha allibrerat la tecla d'accés ràpid</translation>
    </message>
</context>
<context>
    <name>AddClientDialog</name>
    <message>
        <location filename="res/AddClientDialogBase.ui" line="20"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/AddClientDialogBase.ui" line="35"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/AddClientDialogBase.ui" line="83"/>
        <source>Ignore auto connect clients</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotkeyDialogBase</name>
    <message>
        <location filename="res/HotkeyDialogBase.ui" line="14"/>
        <source>Hotkey</source>
        <translation type="finished">Accés Ràpid</translation>
    </message>
    <message>
        <location filename="res/HotkeyDialogBase.ui" line="20"/>
        <source>Enter the specification for the hotkey:</source>
        <translation type="finished">Entrar l'especificació per la tecla d'accés ràpid</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/MainWindow.cpp" line="790"/>
        <source>&amp;Start</source>
        <translation type="finished">&amp;Engegar</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="237"/>
        <source>&amp;File</source>
        <translation type="finished">&amp;Arxiu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="238"/>
        <source>&amp;Edit</source>
        <translation type="finished">&amp;Editar</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="239"/>
        <source>&amp;Window</source>
        <translation type="finished">&amp;Finestra</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="240"/>
        <source>&amp;Help</source>
        <translation type="finished">&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="364"/>
        <source>&lt;p&gt;Your version of Barrier is out of date. Version &lt;b&gt;%1&lt;/b&gt; is now available to &lt;a href=&quot;%2&quot;&gt;download&lt;/a&gt;.&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;Version %1 is now available, &lt;a href=&quot;%2&quot;&gt;visit website&lt;/a&gt;.&lt;/p&gt;</oldsource>
        <translation type="finished">&lt;p&gt;La teva versió de Barrier està desactualitzada. La nova versió &lt;b&gt;%1&lt;/b&gt; està ara disponible per &lt;a href=&quot;%2&quot;&gt;descarregar&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="577"/>
        <source>Program can not be started</source>
        <translation type="finished">El programa no ha pogut iniciar-se</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="577"/>
        <source>The executable&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;could not be successfully started, although it does exist. Please check if you have sufficient permissions to run this program.</source>
        <translation type="finished">L'executable &lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;no ha pogut ser iniciat correctament, tot i que aquest existeix. Si us plau revisa si tens permisos suficients per executar aquest programa.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="596"/>
        <source>Barrier client not found</source>
        <translation type="finished">No s'ha trobat cap client de Barrier</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="597"/>
        <source>The executable for the barrier client does not exist.</source>
        <translation type="finished">L'executable del client de Barrier no existeix.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="625"/>
        <source>Hostname is empty</source>
        <translation type="finished">El nom de Host està buit</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="626"/>
        <source>Please fill in a hostname for the barrier client to connect to.</source>
        <translation type="finished">Si us plau completa el camp nom de host per al client de Barrier per connectar-t'hi.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="646"/>
        <source>Cannot write configuration file</source>
        <translation type="finished">No es pot escriure el fitxer de configuració</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="646"/>
        <source>The temporary configuration file required to start barrier can not be written.</source>
        <translation type="finished">No s'ha pogut escriure al fitxer de configuració temporal requerit per iniciar Barrier </translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="659"/>
        <source>Configuration filename invalid</source>
        <translation type="finished">Nom del fitxer de configuració invàlid</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="660"/>
        <source>You have not filled in a valid configuration file for the barrier server. Do you want to browse for the configuration file now?</source>
        <translation type="finished">No has omplert un arxiu de configuració vàlid per al servidor de Barrier. Vols veure ara el fitxer de configuració?</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="688"/>
        <source>Barrier server not found</source>
        <translation type="finished">No s'ha trobat el Servidor de Barrier</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="689"/>
        <source>The executable for the barrier server does not exist.</source>
        <translation type="finished">L'executable del servidor de Barrier no existeix.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="764"/>
        <source>Barrier terminated with an error</source>
        <translation type="finished">Barrier ha finalitzat degut a un error</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="764"/>
        <source>Barrier terminated unexpectedly with an exit code of %1.&lt;br&gt;&lt;br&gt;Please see the log output for details.</source>
        <translation type="finished">Barrier ha finalitzat inesperadament amb el codi d'error %1.&lt;br&gt;&lt;br&gt;Si us plau mira el log de sortida per més detalls.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="783"/>
        <source>&amp;Stop</source>
        <translation type="finished">A&amp;turar</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1038"/>
        <source>Please add the server (%1) to the grid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1044"/>
        <source>Please drag the new client screen (%1) to the desired position on the grid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1147"/>
        <source>Failed to detect system architecture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1165"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1189"/>
        <source>Failed to download Bonjour installer to location: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1226"/>
        <source>Do you want to enable auto config and install Bonjour?

This feature helps you establish the connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1270"/>
        <source>Auto config feature requires Bonjour.

Do you want to install Bonjour?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="815"/>
        <source>Barrier is starting.</source>
        <translation type="finished">Barrier està engegant-se.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="809"/>
        <source>Barrier is running.</source>
        <translation type="finished">Barrier està executant-se.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="819"/>
        <source>Barrier is not running.</source>
        <translation type="finished">Barrier no s'està executant.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="870"/>
        <source>Unknown</source>
        <translation type="finished">Desconegut </translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1146"/>
        <location filename="src/MainWindow.cpp" line="1225"/>
        <location filename="src/MainWindow.cpp" line="1269"/>
        <source>Barrier</source>
        <translation type="finished">Barrier</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="987"/>
        <source>Browse for a barriers config file</source>
        <translation type="finished">Mostrar el fitxer de configuració de Sygergy</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="408"/>
        <source>Barrier is now connected, You can close the config window. Barrier will remain connected in the background.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="434"/>
        <source>Security question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="435"/>
        <source>Do you trust this fingerprint?

%1

This is a server fingerprint. You should compare this fingerprint to the one on your server's screen. If the two don't match exactly, then it's probably not the server you're expecting (it could be a malicious user).

To automatically trust this fingerprint for future connections, click Yes. To reject this fingerprint and disconnect from the server, click No.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1000"/>
        <source>Save configuration as...</source>
        <translation type="finished">Desar configuració com...</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1004"/>
        <source>Save failed</source>
        <translation type="finished">Error al guardar</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1004"/>
        <source>Could not save configuration to file.</source>
        <translation type="finished">No es pot guardar la configuració a l'arxiu.</translation>
    </message>
</context>
<context>
    <name>MainWindowBase</name>
    <message>
        <location filename="res/MainWindowBase.ui" line="26"/>
        <source>Barrier</source>
        <translation type="finished">Barrier</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="90"/>
        <source>Ser&amp;ver (share this computer's mouse and keyboard):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="243"/>
        <source>Screen name:</source>
        <translation type="finished">Nom pantalla:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="257"/>
        <source>&amp;Server IP:</source>
        <translation type="finished">IP del Servidor:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="380"/>
        <location filename="res/MainWindowBase.ui" line="409"/>
        <source>&amp;Start</source>
        <translation type="finished">&amp;Engegar</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="181"/>
        <source>Use existing configuration:</source>
        <translation type="finished">Utilitzar la configuració actual:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="190"/>
        <source>&amp;Configuration file:</source>
        <translation type="finished">Fitxer &amp;configuració:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="210"/>
        <source>&amp;Browse...</source>
        <translation type="finished">&amp;Mostrar...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="147"/>
        <source>Configure interactively:</source>
        <translation type="finished">Configurar interactivament:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="159"/>
        <source>&amp;Configure Server...</source>
        <translation type="finished">&amp;Configurar Servidor...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="350"/>
        <source>Ready</source>
        <translation type="finished">Llest</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="296"/>
        <source>Log</source>
        <translation type="finished">Log</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="373"/>
        <source>&amp;Reload</source>
        <translation type="finished">Aplicar</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="107"/>
        <source>IP addresses:</source>
        <translation type="finished">Adreces IP:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="131"/>
        <source>Fingerprint:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="228"/>
        <source>&amp;Client (use another computer's mouse and keyboard):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="270"/>
        <source>Auto config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="390"/>
        <source>&amp;About Barrier...</source>
        <translation type="finished">En &amp;quant a Barrier...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="398"/>
        <source>&amp;Quit</source>
        <translation type="finished">&amp;Sortir</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="401"/>
        <source>Quit</source>
        <translation type="finished">Sortir</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="412"/>
        <source>Run</source>
        <translation type="finished">Executa</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="423"/>
        <source>S&amp;top</source>
        <translation type="finished">A&amp;turar</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="426"/>
        <source>Stop</source>
        <translation type="finished">Aturar</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="434"/>
        <source>S&amp;how Status</source>
        <translation type="finished">&amp;Mostrar Estat</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="442"/>
        <source>&amp;Hide</source>
        <translation type="finished">A&amp;maga</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="445"/>
        <source>Hide</source>
        <translation type="finished">Amaga</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="453"/>
        <source>&amp;Show</source>
        <translation type="finished">Mo&amp;stra</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="456"/>
        <source>Show</source>
        <translation type="finished">Mostra</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="464"/>
        <source>Save configuration &amp;as...</source>
        <translation type="finished">&amp;Guardar configuració com...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="467"/>
        <source>Save the interactively generated server configuration to a file.</source>
        <translation type="finished">Guardar la configuració del servidor generada interactivament a un fitxer.</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="475"/>
        <source>Settings</source>
        <translation type="finished">Configuració</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="478"/>
        <source>Edit settings</source>
        <translation type="finished">Editar configuració</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="486"/>
        <source>Run Wizard</source>
        <translation type="finished">Executar Assistent</translation>
    </message>
</context>
<context>
    <name>NewScreenWidget</name>
    <message>
        <location filename="src/NewScreenWidget.cpp" line="32"/>
        <source>Unnamed</source>
        <translation type="finished">Sense nom</translation>
    </message>
</context>
<context>
    <name>PluginManager</name>
    <message>
        <location filename="src/PluginManager.cpp" line="58"/>
        <source>Failed to get plugin directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="63"/>
        <source>Failed to get profile directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="136"/>
        <source>Failed to download plugin '%1' to: %2
%3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="167"/>
        <source>Could not get Windows architecture type.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="191"/>
        <source>Could not get Linux architecture type.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginWizardPage</name>
    <message>
        <location filename="res/PluginWizardPageBase.ui" line="14"/>
        <source>Setup Barrier</source>
        <translation type="finished">Configurar Barrier</translation>
    </message>
    <message>
        <location filename="res/PluginWizardPageBase.ui" line="101"/>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="72"/>
        <source>Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="80"/>
        <location filename="src/PluginWizardPage.cpp" line="201"/>
        <source>Setup complete.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="93"/>
        <source>Downloading '%1' plugin (%2/%3)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="104"/>
        <source>Plugins installed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="120"/>
        <source>Generating SSL certificate...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="170"/>
        <source>Downloading plugin: %1 (1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="239"/>
        <source>Getting plugin list...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="src/MainWindow.cpp" line="60"/>
        <source>All files (*.*)</source>
        <translation type="finished">Tots els arxius (*.*)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="60"/>
        <source>Barrier Configurations (*.sgc)</source>
        <translation type="finished">Configuracions Barrier (*.sgc)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="67"/>
        <source>Barrier Configurations (*.conf)</source>
        <translation type="finished">Configuracions Barrier (*.conf)</translation>
    </message>
    <message>
        <location filename="src/main.cpp" line="119"/>
        <source>System tray is unavailable, quitting.</source>
        <translation type="finished">La safata del sistema no està disponible, sortint.</translation>
    </message>
</context>
<context>
    <name>ScreenSettingsDialog</name>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="67"/>
        <source>Screen name is empty</source>
        <translation type="finished">El nom de pantalla és buit</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="68"/>
        <source>The screen name cannot be empty. Please either fill in a name or cancel the dialog.</source>
        <translation type="finished">El nom de pantalla no pot estar buit. Si us plau introdueix un nom o cancel·la el diàleg.</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="83"/>
        <source>Screen name matches alias</source>
        <translation type="finished">Nom de pantalla coincideix amb l'àlies</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="84"/>
        <source>The screen name cannot be the same as an alias. Please either remove the alias or change the screen name.</source>
        <translation type="finished">El nom de pantalla no pot ser el mateix que un àlies. Si us plau treu l'àlies o bé canvia el nom de la pantalla.</translation>
    </message>
</context>
<context>
    <name>ScreenSettingsDialogBase</name>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="14"/>
        <source>Screen Settings</source>
        <translation type="finished">Configuració Pantalla</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="22"/>
        <source>Screen &amp;name:</source>
        <translation type="finished">&amp;Nom pantalla:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="42"/>
        <source>A&amp;liases</source>
        <translation type="finished">À&amp;lies</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="57"/>
        <source>&amp;Add</source>
        <translation type="finished">A&amp;fegir</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="74"/>
        <source>&amp;Remove</source>
        <translation type="finished">Elimina&amp;r</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="97"/>
        <source>&amp;Modifier keys</source>
        <translation type="finished">&amp;Modificar claus</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="106"/>
        <source>&amp;Shift:</source>
        <translation type="finished">&amp;Shift:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="117"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="164"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="211"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="258"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="305"/>
        <source>Shift</source>
        <translation type="finished">Shift</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="122"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="169"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="216"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="263"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="310"/>
        <source>Ctrl</source>
        <translation type="finished">Ctrl</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="127"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="174"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="221"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="268"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="315"/>
        <source>Alt</source>
        <translation type="finished">Alt</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="132"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="179"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="226"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="273"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="320"/>
        <source>Meta</source>
        <translation type="finished">Meta</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="137"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="184"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="231"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="278"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="325"/>
        <source>Super</source>
        <translation type="finished">Super</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="142"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="189"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="236"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="283"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="330"/>
        <source>None</source>
        <translation type="finished">Cap</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="150"/>
        <source>&amp;Ctrl:</source>
        <translation type="finished">&amp;Ctrl:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="197"/>
        <source>Al&amp;t:</source>
        <translation type="finished">Al&amp;t:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="244"/>
        <source>M&amp;eta:</source>
        <translation type="finished">M&amp;eta:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="291"/>
        <source>S&amp;uper:</source>
        <translation type="finished">S&amp;uper:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="358"/>
        <source>&amp;Dead corners</source>
        <translation type="finished">&amp;Cantonades mortes</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="367"/>
        <source>Top-left</source>
        <translation type="finished">Amunt-esquerra</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="374"/>
        <source>Top-right</source>
        <translation type="finished">Amunt-dreta</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="381"/>
        <source>Bottom-left</source>
        <translation type="finished">Avall-esquerra</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="388"/>
        <source>Bottom-right</source>
        <translation type="finished">Avall-dreta</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="397"/>
        <source>Corner Si&amp;ze:</source>
        <translation type="finished">Mida cantonada:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="428"/>
        <source>&amp;Fixes</source>
        <translation type="finished">&amp;Fixes</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="437"/>
        <source>Fix CAPS LOCK key</source>
        <translation type="finished">Arreglar tecla CAPS LOCK</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="444"/>
        <source>Fix NUM LOCK key</source>
        <translation type="finished">Arreglar tecla NUM LOCK</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="451"/>
        <source>Fix SCROLL LOCK key</source>
        <translation type="finished">Arreglar tecla SCROLL LOCK</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="458"/>
        <source>Fix XTest for Xinerama</source>
        <translation type="finished">Arreglar XTest per Xinerama</translation>
    </message>
</context>
<context>
    <name>ScreenSetupModel</name>
    <message>
        <location filename="src/ScreenSetupModel.cpp" line="51"/>
        <source>&lt;center&gt;Screen: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Double click to edit settings&lt;br&gt;Drag screen to the trashcan to remove it</source>
        <translation type="finished">&lt;center&gt;Pantalla: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Doble clic per editar configuració &lt;br&gt;Arrossega la pantalla a la paperera per eliminar-la</translation>
    </message>
</context>
<context>
    <name>ServerConfigDialog</name>
    <message>
        <location filename="src/ServerConfigDialog.cpp" line="75"/>
        <source>Configure server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerConfigDialogBase</name>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="14"/>
        <source>Server Configuration</source>
        <translation type="finished">Configuració Servidor</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="24"/>
        <source>Screens and links</source>
        <translation type="finished">Pantalles i enllaços</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="35"/>
        <source>Drag a screen from the grid to the trashcan to remove it.</source>
        <translation type="finished">Arrossega una pantalla de la graella a la paperera per eliminar-la.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="60"/>
        <source>Configure the layout of your barrier server configuration.</source>
        <translation type="finished">Configura la disposició de configuració del teu servidor barrier.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="73"/>
        <source>Drag this button to the grid to add a new screen.</source>
        <translation type="finished">Arrossega aquest botó a la graella per afegir una nova pantalla.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="128"/>
        <source>Drag new screens to the grid or move existing ones around.
Drag a screen to the trashcan to delete it.
Double click on a screen to edit its settings.</source>
        <translation type="finished">Arrossega noves pantalles a la graella o mou les actuals al voltant.
Arrossega una pantalla a la paperera per eliminar-la.
Fes doble clic a una pantalla per editar la seva configuració.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="157"/>
        <source>Hotkeys</source>
        <translation type="finished">Accés ràpid</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="163"/>
        <source>&amp;Hotkeys</source>
        <translation type="finished">&amp;Accés ràpid</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="175"/>
        <source>&amp;New</source>
        <translation type="finished">&amp;Nou</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="185"/>
        <source>&amp;Edit</source>
        <translation type="finished">&amp;Editar</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="195"/>
        <source>&amp;Remove</source>
        <translation type="finished">Elimina&amp;r</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="218"/>
        <source>A&amp;ctions</source>
        <translation type="finished">A&amp;ccions</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="230"/>
        <source>Ne&amp;w</source>
        <translation type="finished">No&amp;u</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="240"/>
        <source>E&amp;dit</source>
        <translation type="finished">E&amp;ditar</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="250"/>
        <source>Re&amp;move</source>
        <translation type="finished">Eli&amp;minar</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="274"/>
        <source>Advanced server settings</source>
        <translation type="finished">Configuracions avançades del servidor</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="280"/>
        <source>&amp;Switch</source>
        <translation type="finished">Can&amp;viar</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="291"/>
        <source>Switch &amp;after waiting</source>
        <translation type="finished">Canvia després d'esperar</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="330"/>
        <location filename="res/ServerConfigDialogBase.ui" line="383"/>
        <location filename="res/ServerConfigDialogBase.ui" line="458"/>
        <source>ms</source>
        <translation type="finished">ms</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="344"/>
        <source>Switch on double &amp;tap within</source>
        <translation type="finished">Canvia a doble &amp;toc a</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="408"/>
        <source>&amp;Options</source>
        <translation type="finished">&amp;Opcions</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="419"/>
        <source>&amp;Check clients every</source>
        <translation type="finished">Comprova clients cada</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="470"/>
        <source>Use &amp;relative mouse moves</source>
        <translation type="finished">Utilitza moviments relatius ratolí</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="480"/>
        <source>S&amp;ynchronize screen savers</source>
        <translation type="finished">Sincronitza protectors de pantalla</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="490"/>
        <source>Don't take &amp;foreground window on Windows servers</source>
        <translation type="finished">No prenguis la finestra en primer pla en Windows servers</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="510"/>
        <source>Ignore auto config clients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="520"/>
        <source>&amp;Dead corners</source>
        <translation type="finished">&amp;Cantonades mortes</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="529"/>
        <source>To&amp;p-left</source>
        <translation type="finished">Amunt-&amp;esquerra</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="536"/>
        <source>Top-rig&amp;ht</source>
        <translation type="finished">Amunt-&amp;dreta</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="543"/>
        <source>&amp;Bottom-left</source>
        <translation type="finished">Avall-&amp;esquerra</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="550"/>
        <source>Bottom-ri&amp;ght</source>
        <translation type="finished">Avall-&amp;dreta</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="572"/>
        <source>Cor&amp;ner Size:</source>
        <translation type="finished">Mida ca&amp;ntonada:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="src/SettingsDialog.cpp" line="131"/>
        <source>Save log file to...</source>
        <translation type="finished">Guardar fitxer log a...</translation>
    </message>
    <message>
        <location filename="src/SettingsDialog.cpp" line="151"/>
        <source>Elevate Barrier</source>
        <translation type="finished">Elevar Barrier</translation>
    </message>
    <message>
        <location filename="src/SettingsDialog.cpp" line="152"/>
        <source>Are you sure you want to elevate Barrier?

This allows Barrier to interact with elevated processes and the UAC dialog, but can cause problems with non-elevated processes. Elevate Barrier only if you really need to.</source>
        <translation type="finished">Estas segur que vols elevar Barrier?
Això permet a Barrier interactuar amb processos elevats i el diàleg del UAC, però pot causar problemes amb processos no elevats. Eleva Barrier només si realment ho necessites.</translation>
    </message>
</context>
<context>
    <name>SettingsDialogBase</name>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="14"/>
        <source>Settings</source>
        <translation type="finished">Configuració</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="32"/>
        <source>Sc&amp;reen name:</source>
        <translation type="finished">Nom pantalla:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="49"/>
        <source>P&amp;ort:</source>
        <translation type="finished">Port:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="78"/>
        <source>&amp;Interface:</source>
        <translation type="finished">&amp;Interfície:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="120"/>
        <source>Elevate mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="127"/>
        <source>&amp;Hide on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="146"/>
        <source>&amp;Network Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="155"/>
        <source>Use &amp;SSL encryption (unique certificate)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="184"/>
        <source>Logging</source>
        <translation type="finished">Logging</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="202"/>
        <source>&amp;Logging level:</source>
        <translation type="finished">Nivell &amp;logging:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="251"/>
        <source>Log to file:</source>
        <translation type="finished">Log a fitxer:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="268"/>
        <source>Browse...</source>
        <translation type="finished">Mostrar...</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="213"/>
        <source>Error</source>
        <translation type="finished">Error</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="107"/>
        <source>&amp;Language:</source>
        <translation type="finished">Idioma:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="20"/>
        <source>&amp;Miscellaneous</source>
        <translation type="finished">Miscel·lània</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="218"/>
        <source>Warning</source>
        <translation type="finished">Advertència</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="223"/>
        <source>Note</source>
        <translation type="finished">Nota</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="228"/>
        <source>Info</source>
        <translation type="finished">Info</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="233"/>
        <source>Debug</source>
        <translation type="finished">Debug</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="238"/>
        <source>Debug1</source>
        <translation type="finished">Debug1</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="243"/>
        <source>Debug2</source>
        <translation type="finished">Debug2</translation>
    </message>
</context>
<context>
    <name>SetupWizard</name>
    <message>
        <location filename="src/SetupWizard.cpp" line="72"/>
        <source>Setup Barrier</source>
        <translation type="finished">Configurar Barrier</translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="113"/>
        <source>Please select an option.</source>
        <translation type="finished">Siusplau tria una opció.</translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="80"/>
        <source>Please enter your email address and password.</source>
        <translation type="finished">Si us plau introdueix la teva adreça d'email i contrasenya.</translation>
    </message>
</context>
<context>
    <name>SetupWizardBase</name>
    <message>
        <location filename="res/SetupWizardBase.ui" line="26"/>
        <source>Setup Barrier</source>
        <translation type="finished">Configurar Barrier</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="30"/>
        <source>Welcome</source>
        <translation type="finished">Benvingut</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="39"/>
        <source>Thanks for installing Barrier!</source>
        <translation type="finished">Gràcies per instal·lar Barrier!</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="114"/>
        <source>Barrier lets you easily share your mouse and keyboard between multiple computers on your desk, and it's Free and Open Source. Just move your mouse off the edge of one computer's screen on to another. You can even share all of your clipboards. All you need is a network connection. Barrier is cross-platform (works on Windows, Mac OS X and Linux).</source>
        <translation type="finished">Barrier et permet compartir fàcilment el ratolí i teclat entre diversos ordinadors al teu escriptori, i és lliure i de codi obert. Només cal moure el punter del ratolí per la vora de la pantalla d'un ordinador a un altre. Fins i tot pots compartir el portapapers. Únicament el que necessites és una connexió de xarxa. Barrier és multiplataforma (funciona en Windows, Mac OS X i Linux).</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="125"/>
        <source>Activate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="131"/>
        <source>&amp;Activate now...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="152"/>
        <source>Email:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="178"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="204"/>
        <source>&lt;a href=&quot;https://symless.com/account/reset/&quot;&gt;Forgot password&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="232"/>
        <source>&amp;Skip activation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="277"/>
        <source>&amp;Server (share this computer's mouse and keyboard)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="290"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;My main mouse and keyboard are connected to this computer. This will allow you to move your mouse over to another computer's screen. There can only be one server in your setup.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="326"/>
        <source>&amp;Client (use another computer's mouse and keyboard)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="339"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;You have already set up a server. This computer will be controlled using the server's mouse and keyboard. There can be many clients in your setup.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="262"/>
        <source>Server or Client?</source>
        <translation type="finished">Servidor o Client?</translation>
    </message>
</context>
<context>
    <name>SslCertificate</name>
    <message>
        <location filename="src/SslCertificate.cpp" line="42"/>
        <source>Failed to get profile directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/SslCertificate.cpp" line="141"/>
        <source>SSL certificate generated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/SslCertificate.cpp" line="170"/>
        <source>SSL fingerprint generated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/SslCertificate.cpp" line="173"/>
        <source>Failed to find SSL fingerprint.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionChecker</name>
    <message>
        <location filename="src/VersionChecker.cpp" line="102"/>
        <source>Unknown</source>
        <translation type="finished">Desconegut </translation>
    </message>
</context>
<context>
    <name>WebClient</name>
    <message>
        <location filename="src/WebClient.cpp" line="44"/>
        <source>An error occurred while trying to sign in. Please contact the helpdesk, and provide the following details.

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="65"/>
        <source>Login failed, invalid email or password.</source>
        <translation type="finished">Ha fallat l'inici de sessió, email o contrasenya incorrectes.</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="78"/>
        <source>Login failed, an error occurred.

%1</source>
        <translation type="finished">Error inici de sessió, hi ha hagut un error.
%1</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="86"/>
        <source>Login failed, an error occurred.

Server response:

%1</source>
        <translation type="finished">Error inici de sessió, hi ha hagut un error.
Resposta del servidor:
%1</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="101"/>
        <source>An error occurred while trying to query the plugin list. Please contact the help desk, and provide the following details.

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="120"/>
        <source>Get plugin list failed, invalid user email or password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="131"/>
        <source>Get plugin list failed, an error occurred.

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="137"/>
        <source>Get plugin list failed, an error occurred.

Server response:

%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZeroconfService</name>
    <message>
        <location filename="src/ZeroconfService.cpp" line="82"/>
        <source>zeroconf server detected: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="91"/>
        <source>zeroconf client detected: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="99"/>
        <location filename="src/ZeroconfService.cpp" line="130"/>
        <source>Zero configuration service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="100"/>
        <source>Error code: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="131"/>
        <source>Unable to start the zeroconf: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="140"/>
        <source>Barrier</source>
        <translation type="finished">Barrier</translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="141"/>
        <source>Failed to get local IP address. Please manually type in server address on your clients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="147"/>
        <location filename="src/ZeroconfService.cpp" line="154"/>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>